;; Tento kod je MODIFIKACI modelu, ktery jiz je obsazen v knihovnach NETloga. Konkretne nektere pasaze jsou kompletne prevzaty z
;; z modelu:
;;
;;   Wilensky, U. (2002). NetLogo PD N-Person Iterated model. http://ccl.northwestern.edu/netlogo/models/PDN-PersonIterated. 
;;   Center for Connected Learning and Computer-Based Modeling, Northwestern Institute on Complex Systems, Northwestern University, Evanston, IL.
;;
;; k nalezeni: Social Science -> (unverified) -> Prisoner's Dilemma -> PD N-Person Iterated

globals [
 LM_list_of_debts ;; Globalni list, ve kterem se ukazuji nesplacene pokuty agentu   
]

breed [atfts atft]    ;; adjusted-tit-for-tat agenti (modri)
breed [reguls regul]  ;; regular agenti (oranzovi)

turtles-own [
  score               ;; Promenna skore, ktera urcuje, jak dobre si agent vede
  strategy            ;; Promenna urcujici, podle jake strategie agent hraje
  delta               ;; Promenna reprezentujici diskontni faktor, urcuje ochotu kooperovat / platit pokuty
  defect-now?         ;; Indikator pro akci, ktera bude v tomto kole nasledovat
  partner-defected?   ;; Indikator pro vyhodnoceni chovani agenta
  partnered?          ;; Je agent momentalne s nekym sparovan? 
  partner             ;; Kdo je s agentem sparovan?
  debt                ;; Vyse nesplacenych dluhu
]

to setup
  ca
  reset-ticks
  create-atfts num-atft [ set strategy "adjusted-tit-for-tat" set color sky]
  create-reguls num-regul [ set strategy "regular" set color orange ]
  LM_lists_init
  ask turtles [
    set debt 0
    set score init-wealth
    ask reguls [set delta delta-reg + random-float 0.25 - random-float 0.25] ;; Oranzovi agenti se lisi svoji deltou (rozpeti je az 0.5)
    ask atfts [set delta 0.8 + random-float 0.2]                             ;; Modri agenti maji vysokou deltu
    set partnered? false
    set partner nobody
    setxy random-xcor random-ycor
    set size 2
    set shape "person"
  ]
end

to step
  clear-last-round                                   ;; Smaz data z minuleho kola
  ask turtles [ partner-up ]                         ;; Najdi partnera
  let partnered-turtles turtles with [ partnered? ]  
  ask partnered-turtles [ select-action ]            ;; Zvol, jak budes hrat
  ask partnered-turtles [ get-payoff ]               ;; Ziskej vysledek setkani
  ask turtles [set score score - cost-of-living]     ;; Kazde kolo se plati fixni castka
  pay-debts                                          ;; Pripadne zaplat vznikle dluhy
  do-dying                                           ;; Je-li score nyni mensi nez 0, prestan fungovat
  change-preferences                                 ;; Koriguje preference oranzovych agentu podle nastaveni (defaultne nic nedela)
  tick
  plot-ave                                           ;; Vykresluje grafy
  plot-delta
  plot-debts
  plot-popul
end

to clear-last-round ;; kompletne prevzato z  Wilensky, U. (2002)
  let partnered-turtles turtles with [ partnered? ]
  ask partnered-turtles [ release-partners ]
end

to partner-up       ;; kompletne prevzato z  Wilensky, U. (2002)
  if (not partnered?) [
    rt (random-float 90 - random-float 90) fd 1
    set partner one-of (turtles-at -1 0) with [ not partnered? ]
    if partner != nobody [
      set partnered? true
      set heading 270
      ask partner [
        set partnered? true
        set partner myself
        set heading 90
      ]
    ]
  ]
end

to release-partners ;; kompletne prevzato z  Wilensky, U. (2002)
  set partnered? false
  set partner nobody
  rt 180
end

to select-action
  if (strategy = "regular") [ regular ]
  if (strategy = "adjusted-tit-for-tat") [ adjusted-tit-for-tat ]
end

to get-payoff
  set partner-defected? [defect-now?] of partner
  ifelse partner-defected? 
  [
    ifelse defect-now? 
    [ ; pokud oba partneri podvadi, dostanou oba payoff D-D. Pokud se tohoto obchodu ucatnil modry agent a pokud protihrac toho druheho nemel zadne dluhy, agent dostane pokutu.
      set score (score + D-D) set label D-D if ([breed] of partner = atfts or breed = atfts) [ 
        if [debt] of partner = 0 [ set debt debt + punishment set LM_list_of_debts replace-item who LM_list_of_debts debt ] ]
    ] 
    [ ; pokud JA kooperuji a druhy podvede.
      set score (score + C-D) set label C-D
    ]
  ] 
  [
    ifelse defect-now? 
    [ ; pokud JA podvedu a druhy kooperuje. Pokud se obchodu ucastnil alespon jeden modry agent, podvodnik dostane pokutu.
      set score (score + D-C) set label D-C if ([breed] of partner = atfts or breed = atfts) [ 
        set debt debt + punishment  
        set LM_list_of_debts replace-item who LM_list_of_debts debt ]
    ] 
    [ ; Zisk z kooperace
      set score (score + C-C) set label C-C 
    ] 
  ]
end

to pay-debts
  ask turtles with [(1 - (Oportunism / 100)) * ((2 * delta) / (1 - delta)) > debt] [   ;; Ochota zaplatit dluhy zavisi na diskontnim faktoru a mire oportunismu.
    set score score - debt  
    set debt 0
    set LM_list_of_debts replace-item who LM_list_of_debts 0 ]
end

to do-dying
  ask turtles with [ score <= 0 ] [die]
end

to change-preferences
  ask reguls [ set delta (delta + random-float delta-plus - random-float delta-minus) ]
  ask reguls [ if delta >= 1 [ set delta 0.999 ] ]
  ask reguls [ if delta <= 0 [ set delta 0.001 ] ]
end

to regular
  set defect-now? (((random-float 1) + (Oportunism / 100)) > delta) ;; cim vyssi diskontni faktor, tim vice inklinuje chovani oraznzovych hracu ke spolupraci.
end

to adjusted-tit-for-tat
  ifelse random 100 < Oportunism
  [ set defect-now? true ]
  [ set partner-defected? item ([who] of partner) LM_list_of_debts != 0 ;; modry hrac tresta vyhradne hrace, kteri nesplaceji pokuty.
  ifelse (partner-defected?) 
  [ set defect-now? true] 
  [ set defect-now? false] ]
  set score score - Law-Merchant-Cost
end

to LM_lists_init
  set LM_list_of_debts []
  let num-turtles count turtles
  repeat num-turtles [ set LM_list_of_debts (fput 0 LM_list_of_debts) ]
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;Vykreslovani grafu


to plot-ave
  let num-of-atfts count atfts
  let num-of-reguls count reguls
  set-current-plot "Average Score"
  set-current-plot-pen "reguls"
  ifelse num-of-reguls > 0 [ plot sum [ score ] of reguls / (num-of-reguls) ] [plot 0]
  set-current-plot-pen "atfts"
  ifelse num-of-atfts > 0 [ plot sum [ score ] of atfts / (num-of-atfts) ] [plot 0]
end

to plot-delta
  let num-of-atfts count atfts
  let num-of-reguls count reguls
  set-current-plot "Average Delta"
  set-current-plot-pen "reguls"
  ifelse num-of-reguls > 0 [ plot sum [ delta ] of reguls / (num-of-reguls) ] [plot 0]
  set-current-plot-pen "atfts"
  ifelse num-of-atfts > 0 [ plot sum [ delta ] of atfts / (num-of-atfts) ] [plot 0]
end

to plot-debts
  let num-of-atfts count atfts
  let num-of-reguls count reguls
  set-current-plot "Average Debt"
  set-current-plot-pen "reguls"
  ifelse num-of-reguls > 0 [ plot sum [ debt ] of reguls / (num-of-reguls) ] [plot 0]
  set-current-plot-pen "atfts"
  ifelse num-of-atfts > 0 [ plot sum [ debt ] of atfts / (num-of-atfts) ] [plot 0]
end

to plot-popul
  let num-of-atfts count atfts
  let num-of-reguls count reguls
  set-current-plot "Number of Merchants"
  set-current-plot-pen "reguls"
  plot num-of-reguls
  set-current-plot-pen "atfts"
  plot num-of-atfts
end
@#$#@#$#@
GRAPHICS-WINDOW
495
12
991
529
16
16
14.73
1
20
1
1
1
0
1
1
1
-16
16
-16
16
1
1
1
ticks
30.0

BUTTON
6
13
69
46
setup
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
144
14
207
47
go
step
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
75
13
138
46
NIL
step
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
7
91
207
124
num-atft
num-atft
0
150
100
1
1
NIL
HORIZONTAL

SLIDER
7
53
207
86
num-regul
num-regul
0
150
100
1
1
NIL
HORIZONTAL

SLIDER
298
91
491
124
Oportunism
Oportunism
0
15
5
1
1
%
HORIZONTAL

SLIDER
299
128
492
161
Law-Merchant-Cost
Law-Merchant-Cost
0
0.5
0.15
0.01
1
NIL
HORIZONTAL

SLIDER
297
12
389
45
C-C
C-C
-5
5
2
1
1
NIL
HORIZONTAL

SLIDER
398
13
490
46
C-D
C-D
-5
5
-3
1
1
NIL
HORIZONTAL

SLIDER
297
52
389
85
D-C
D-C
-5
5
3
1
1
NIL
HORIZONTAL

SLIDER
398
53
490
86
D-D
D-D
-5
5
0
1
1
NIL
HORIZONTAL

PLOT
3
278
492
530
Average Score
Ticks
Average Score
0.0
100.0
20.0
30.0
true
true
"" ""
PENS
"atfts" 1.0 0 -13791810 true "" ""
"reguls" 1.0 0 -955883 true "" ""

SLIDER
7
126
179
159
delta-plus
delta-plus
0
0.001
0
0.0001
1
NIL
HORIZONTAL

SLIDER
7
161
179
194
delta-minus
delta-minus
0
0.001
0
0.0001
1
NIL
HORIZONTAL

PLOT
3
533
239
688
Average Delta
Ticks
Average delta
0.0
10.0
0.0
1.0
true
false
"" ""
PENS
"atfts" 1.0 0 -13791810 true "" ""
"reguls" 1.0 0 -955883 true "" ""

SLIDER
299
165
492
198
cost-of-living
cost-of-living
0
0.25
0.15
0.01
1
NIL
HORIZONTAL

SLIDER
299
203
492
236
init-wealth
init-wealth
0
300
50
1
1
NIL
HORIZONTAL

PLOT
242
533
492
688
Average Debt
Ticks
Average Debt
0.0
10.0
0.0
5.0
true
false
"" ""
PENS
"atfts" 1.0 0 -13791810 true "" ""
"reguls" 1.0 0 -955883 true "" ""

SLIDER
300
240
492
273
punishment
punishment
0.01
10
3.11
0.1
1
NIL
HORIZONTAL

SLIDER
6
196
178
229
delta-reg
delta-reg
0
0.85
0.55
0.01
1
NIL
HORIZONTAL

SLIDER
6
231
208
264
spawn-num
spawn-num
0
500
50
1
1
NIL
HORIZONTAL

BUTTON
212
231
288
265
Create reguls
  create-reguls spawn-num [ \n    set strategy \"regular\" \n    set color orange \n    set score init-wealth\n    set debt 0\n    set delta delta-reg + random-float 0.2 - random-float 0.2\n    set partnered? false\n    set partner nobody\n    setxy random-xcor random-ycor\n    set size 2\n    set shape \"person\" ]\n  repeat spawn-num [ set LM_list_of_debts (lput 0 LM_list_of_debts) ]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
496
533
992
688
Number of Merchants
NIL
# Merchants
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"atfts" 1.0 0 -13791810 true "" ""
"reguls" 1.0 0 -955883 true "" ""

TEXTBOX
210
98
242
116
Modri
11
95.0
1

TEXTBOX
210
64
255
82
Oranzovi
11
25.0
1

@#$#@#$#@
## O CO JDE?

Cílem tohoto modelu je pomocí multiagentní simulace prozkoumat, jakým způsobem mohl fungovat středověký obchod. Teoretickým východiskem modelu je článek Milgrom et al. (1990), ve kterém autoři modelovali obchodní styky obchodníků ve středověku jako vězňovo dilemma, tj. situaci, kdy má každá strana důvod protistranu podvést (např. nedodat zboží požadované kvality, nezaplatit řádně a včas apod.). Pro nekonečně opakované hry se jako velmi výhodná jeví strategie tit-for-tat; realita středověkého obchodu však neodpovídá situaci, kdy by se obchodník stále potýkal jen s velmi omezeným počtem obchodníků a mohl se orientovat pouze dle své osobní zkušenosti s ními. 

Ve svém článku navrhli strategii, která je, narozdíl od strategie tit-for-tat, vhodná pro agenty čelící velkému počtu různých protihráčů. Řešením je strategie nazvaná adjusted-tit-for-tat, která se opírá o existenci dostupných informací o minulých akcích obchodníků. Tuto službu údajně měl zprostředkovát tzv. Law Merchant. Law Merchant, pokud byl přizván k dohlížení průběhu obchodu, podvodníkům uděloval pokuty, které ovšem nebyly vymahatelné kvůli absenci státního aparátu a které se zaznamenávaly do veřejného "registru" a byly pak přistupné ostatním zájemcům o informace.

Tento model je vychází z procedur modelu vězňova dilematu Wilensky (2002), který je součástí distribuce NetLoga.

## JAK TO FUNGUJE

Na hrací ploše se náhodně pohybuje množství agentů, kteří spolu při setkání hrají vězňovo dilema. Výchozí výplaty ukazuje následující matice:

                 | Partner's Action
      Turtle's   |
       Action    |   C       D
     ------------|-----------------
           C     |   2      -3
     ------------|-----------------
           D     |   3       0
     ------------|-----------------
      (C = Cooperate, D = Defect)

Po každé hře si agent v závislosti na výsledku upraví svoje aktuální bohatství ("score"). Pokud bohatství spatne pod 0 (včetně) agent se přestane na tomto trhu angažovat / umírá.

Chování agentů ovliňuje jim přiřčená strategie ("strategy") a jejich diskontní faktor ("delta", 0 < delta < 1).

Zadefinovány jsou dva druhy agentů. Modří (hrající strategii "adjusted-tit-for-tat") a oranžoví (hrající strategii, kterou jsem nazval "regular"; popsano později). 

a) Modří agenti mají přístup do globálního listu neuhrazených pokut ("debts") a pokud se setkají s protihrácem, který má neuhrazené pokuty, hrají strategii D (za jiných okolností kooperují). Existují dvě možnosti jak získat pokutu (platí pro všechny agenty).

      1) Pokutu agent dostane, pokud ve hře, které se účastnil alespoň jeden modrý hráč, podvedl svého protihráče, který kooperoval.

      2) Pokutu agent dostane, pokud ve hře, které se účastnil alespoň jeden modrý hráč, podvedl svého protihráče, který taky podváděl a zároveň neměl žádné neuhrazené pokuty.

Po obdržení pokuty se každý agent dobrovolně rozhodne, zda ji zaplatí a zbaví se tak stigmatu podvodníka. Toto rozhodnutí je odvislé od jeho diskontního faktoru a agent platí pokuty, pokud jsou menší než 2 * delta / (1 - delta). Tedy trpělivější agent je ochotnější platit pokuty, protože častěji hraje kooperativní akci; krátkozrací podvodníci nejsou ochotni nést náklady pokuty, když stejně chtejí podvádět (pociťují malou hodnotu v ziscích z dlouhodobé kooperace).

b) Oranžový agent spolupracuje v každém kole s pravděpodobností delta.

## JAK TO POUŽÍT

### Tlačítka

SETUP -- Sestav výchozí prostředí modelu.

STEP -- Proveď jeden krok modelu.

GO -- Spusť model.

CREATE REGULS -- Vytvoří novou vlnu oranžových agentů.

### Posuvníky

NUM-REGUL -- Počáteční počet oranžových agentů. Výchozí hodnota 100.

NUM-ATFT -- Počáteční počet modrých agentů. Výchozí hodnota 100.

DELTA-PLUS -- Maximálně o kolik se v každém kroku modelu zvýší delta oranžových agentů. Výchozí hodnota 0.

DELTA-MINUS -- Maximálně o kolik se v každém kroku modelu zvýší delta oranžových agentů. Výchozí hodnota 0.

DELTA-REG -- Určuje průměrnou hodnotu oranžových agentů. K tomuto číslu se přičtě číslo od -0.25 do 0.25. Výchozí hodnota 0.55.

SPAWN-NUM -- Kolik nových oranžových agentů s výchozím skóre rovným aktuální hodnotě init-wealth a s výchozí deltou podle aktuální hodnoty proměnné delta-reg.

C-C -- Výplata v případe vzájemné kooperace, výchozí nastavení 2.

C-D -- Výplata v případě, že agent kooperoval, ale druhý jej podvedl, výchozí nastavení -3.

D-C -- Výplata v případě, že agent podváděl, ale druhý kooperoval, výchozí nastavení 3.

D-D -- Výplata v případě vzájemného podvádění, výchozí nastavení 0.

OPORTUNISM -- Tato proměnná zvyšuje či zavádí pravděpodobnost, se kterou všichni agenti hrají akci D bez ohledu na chování protihráče. Výchozí hodnota 5 %.

LAW-MERCHANT-COST -- Výše dodatečného nákladu, který zaplatí každý modrý agent po každé hře. Výchozí nastavení 0.15.

COST-OF-LIVING -- Výše nákladů, které platí všichni agenti každé kolo. Výchozí nastavení 0.15.

INIT-WEALTH -- Počátečné hodnota score každého agenta. Výchozí hodnota 30.

PUNISHMENT -- Výše pokuty, která se uděluje za porušení pravidel.Výchozí hodnota 3.11.

### Grafy

AVERAGE SCORE -- Vykresluje průměrné skóre aktivních / žijících modrých a oranžových agentů.

AVERAGE DELTA -- Vykresluje průměrný diskontní faktor aktivních / žijících modrých a oranžových agentů.

AVERAGE DEBTS -- Vykresluje průměrnou hodnotu neuhrazených pokut aktivních / žijících modrých a oranžových agentů.

NUMBER OF MERCHANTS -- Vykresluje počet aktivních / žijících modrých a oranžových agentů.


## K POVŠIMNUTÍ

Při výchozích hodnotách je patrné, že ze začátku se nechá každý modrý agent oranžovými napálit a oranžoví mají tedy prvních pár kol náskok. Modří agenti jsou ochotni platit i velmi vysoké pokuty, ale oranžoví, kteří mají nízkou deltu a škodí nejčastěji, pokuty platit nechtějí. Kvůli tomu se jim začnou kumulovat dluhy (nárůst Average debt) a začnou být ostrakizováni modrými agenty. Po nějaké době tito oranžoví agenti odejdou z trhu / zemřou (je viděl, že v průměru se delta oranžových zvýší a zároveň poklesne jejich počet).

Poté, co zmizí nejméně kooperativní agenti dojde k růstu výdělků. Co se stane nyní, pokud snížíte výši pokut?

Co by se stalo, kdyby takto nízká byla od začátku?

Co se stane, pokud by na začátku byla výše pokut co nejvyšší? Kdo odejde první -- trpěliví kooperující agenti nebo krátkozrací agenti?

## CO ZKUSIT

Jak se chová model pro různé hodnoty delta-red, Oportunism, Law-Merchant-Cost, cost-of-living a Punishment?

Co se stane, kdy do modelu vpustíte 500 velmi trpělivých oranžových agentů a co, když přidáte 500 netrpělivých (delta-reg = 0)? Záleži při tom na tom, kolik má průměrný modrý agent napořeno?

## ROZŠÍŘENÍ MODELU

Je vidět, že výše pokuty výrazně ovlivňuje udržitelnost obchodu. Z počátku pokuty fungují k identifikaci agentů, kteří nejsou příliš ochotní kooperovat, později ale spíše brzdí již vyselektované kooperativní agenty. Model by se dal upravit, aby se výše trestu určovala endogenně v závislosti na chování nových agentů, kteří by do modelu vstupovali každé kolo.


## SOUVISEJÍCÍ MODELY

V distribuci NetLogo k nalezeni: Social Science -> (unverified) -> Prisoner's Dilemma

## ZDROJE

Milgrom, Paul R., Douglass C. North a Barry R. Weingast. The role of institutions in the revival of trade: the Law Merchant, private judges, and the Champagne Fairs. Economics and Politics. 1990, vol. 2, issue 1, s. 1-23. DOI: 10.1111/j.1468-0343.1990.tb00020.x.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.0.4
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="experiment" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>step</go>
    <timeLimit steps="3000"/>
    <exitCondition>(count atfts = 0) or (count reguls = 0)</exitCondition>
    <metric>mean [score] of atfts</metric>
    <metric>mean [score] of reguls</metric>
    <metric>sum [score] of atfts</metric>
    <metric>sum [score] of reguls</metric>
    <metric>count atfts</metric>
    <metric>count reguls</metric>
    <steppedValueSet variable="punishment" first="0.01" step="0.5" last="9.91"/>
    <steppedValueSet variable="delta-reg" first="0" step="0.075" last="0.75"/>
  </experiment>
  <experiment name="typicky prubeh" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>step</go>
    <timeLimit steps="1500"/>
    <exitCondition>(count atfts = 0) or (count reguls = 0)</exitCondition>
    <metric>mean [score] of atfts</metric>
    <metric>mean [score] of reguls</metric>
  </experiment>
  <experiment name="experiment" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>step</go>
    <timeLimit steps="3000"/>
    <exitCondition>(count atfts = 0) or (count reguls = 0)</exitCondition>
    <metric>mean [score] of atfts</metric>
    <metric>mean [score] of reguls</metric>
    <metric>sum [score] of atfts</metric>
    <metric>sum [score] of reguls</metric>
    <metric>count atfts</metric>
    <metric>count reguls</metric>
    <steppedValueSet variable="num-regul" first="0" step="10" last="1000"/>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 1.0 0.0
0.0 1 1.0 0.0
0.2 0 1.0 0.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
